Overview
========

It may be convenient for python users to have available physical
constants from the
`GNU Scientific Library <https://www.gnu.org/software/gsl/>`_
without installing GSL itself.  This package makes those constants
available directly.

Installation
------------

Install from `PyPI <https://pypi.org/project/gslconsts>`_ with pip by
typing in your favorite terminal::

    $ pip install gslconsts

Usage
-----

To learn how to use the package, follow the
`tutorials <http://gslconsts.readthedocs.io/en/latest/tutorials.html>`_.

Authors
-------

- Bradley S. Meyer <mbradle@g.clemson.edu>

Contribute
----------

- Issue Tracker: `<https://github.com/mbradle/gslconsts/issues/>`_
- Source Code: `<https://github.com/mbradle/gslconsts/>`_

License
-------

The project is licensed under the GNU Public License v3 (or later).

Documentation
-------------

The project documentation is available at `<https://gslconsts.readthedocs.io>`_.

